@@ -42,6 +42,8 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, TaskStatus):
             return obj.__dict__
+        elif isinstance(obj, AxisAngle):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -88,6 +90,8 @@ class JsonDecoder(json.JSONDecoder):
                 return ProgramState(**obj)
             if '_type' in obj and obj['_type'] == 'task_status':
                 return TaskStatus(**obj)
+            if '_type' in obj and obj['_type'] == 'axis_angle':
+                return AxisAngle(**obj)
         return obj
 
 
