@@ -108,3 +108,26 @@ class ConfirmTask:
 
     def __repr__(self):
         return f"<task_uuid={self.task_uuid}>"
+
+
+class TaskStatus:
+    PRECONDITION = "precondition"
+    WAITING = "waiting"
+    IN_PROGRESS = "in_progress"
+    COMPLETED = "completed"
+
+    def __init__(self, task_uuid: str, status: str, _type: str = ''):
+        self._type = 'task_status'
+        self.task_uuid = task_uuid
+        self.status = status
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, TaskStatus):
+            return other.task_uuid == self.task_uuid and other.status == self.status
+        return False
+
+    def __ne__(self, other: object) -> bool:
+        return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"<task_uuid={self.task_uuid},status={self.status}>"
