@@ -105,11 +105,12 @@ class Pose:
 
 class AxisAngle:
 
-    def __init__(self, angle: float, x: float, y: float, z: float):
-        self._angle = angle
-        self._x = x
-        self._y = y
-        self._z = z
+    def __init__(self, angle: float, x: float, y: float, z: float, _type: str = ''):
+        self._type = "axis_angle"
+        self.angle = angle
+        self.x = x
+        self.y = y
+        self.z = z
 
     @staticmethod
     def from_rotation_vec(rotation: Vector3) -> 'AxisAngle':
@@ -182,32 +183,32 @@ class AxisAngle:
         return AxisAngle(angle, x, y, z)
 
     def get_rotation_vector(self) -> Vector3:
-        return Vector3(self._x * self._angle, self._y * self._angle, self._z * self._angle)
+        return Vector3(self.x * self.angle, self.y * self.angle, self.z * self.angle)
 
     def get_rotation_matrix(self) -> List[List[float]]:
-        if self._angle == 0:
+        if self.angle == 0:
             return [[1, 0, 0], [0, 1, 0], [0, 0, 1]]
 
-        c = math.cos(self._angle)
-        s = math.sin(self._angle)
+        c = math.cos(self.angle)
+        s = math.sin(self.angle)
         t = 1.0 - c
 
-        m00 = c + self._x * self._x * t
-        m11 = c + self._y * self._y * t
-        m22 = c + self._z * self._z * t
+        m00 = c + self.x * self.x * t
+        m11 = c + self.y * self.y * t
+        m22 = c + self.z * self.z * t
 
-        tmp1 = self._x * self._y * t
-        tmp2 = self._z * s
+        tmp1 = self.x * self.y * t
+        tmp2 = self.z * s
         m10 = tmp1 + tmp2
         m01 = tmp1 - tmp2
 
-        tmp1 = self._x * self._z * t
-        tmp2 = self._y * s
+        tmp1 = self.x * self.z * t
+        tmp2 = self.y * s
         m20 = tmp1 + tmp2
         m02 = tmp1 - tmp2
 
-        tmp1 = self._y * self._z * t
-        tmp2 = self._x * s
+        tmp1 = self.y * self.z * t
+        tmp2 = self.x * s
         m21 = tmp1 + tmp2
         m12 = tmp1 - tmp2
 
