@@ -1,7 +1,7 @@
 from unittest import TestCase
 
 from holour import json_encode, json_decode
-from holour.msg import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask
+from holour.msg import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask, TaskStatus
 
 
 class TestAddProcess(TestCase):
@@ -160,3 +160,35 @@ class TestConfirmTask(TestCase):
         expected, got = 'uuid', f'{confirm_task}'
 
         assert expected in got, f"Expected {expected} in got: {got}"
+
+
+class TestTaskStatus(TestCase):
+
+    def test_task_status(self):
+        task_status = TaskStatus('uuid', TaskStatus.WAITING)
+        task_status_string = json_encode(task_status)
+        expected_string = '{"_type": "task_status", "task_uuid": "uuid", "status": "waiting"}'
+
+        assert type(task_status_string) == str
+        assert task_status_string == expected_string, f"Expected {expected_string}, got: {task_status_string}"
+
+        task_status_decoded = json_decode(task_status_string)
+        assert type(task_status_decoded) == TaskStatus, f"Got: {type(task_status_decoded)}. " \
+                                                          f"Expected {ConfirmTask}"
+        assert task_status_decoded == task_status, f"The decoded object: {task_status_decoded} " \
+                                                     f"must be equal to the encoded: {task_status}"
+
+    def test_task_status_equals(self):
+        co1 = TaskStatus('uuid', TaskStatus.WAITING)
+        co2 = TaskStatus('uuid', TaskStatus.WAITING)
+        co3 = TaskStatus('uuid', TaskStatus.COMPLETED)
+
+        assert co1 == co2
+        assert co1 != co3
+        assert co1 != "not status"
+
+    def test_task_status_repr(self):
+        task_status = TaskStatus('uuid', TaskStatus.WAITING)
+        expected, got = 'waiting', f'{task_status}'
+
+        assert expected in got, f"Expected {expected} in got: {got}"
